==> nested_json_to_csv-1.1.9.tgz: package/nestedJsonToCsv.js <==
const general = require('./generalFunctions.js');

exports.nestedJsonToCsv = (json, headers, multiples) => {

    if (headers == undefined || headers == []) {
        general.printError("Please pass an array of strings as a second parameter(headers)");
        //TODO: add a documentation link for this
        throw new Error;
    }

    let csv = "";

    csv = addHeaders(headers, csv);
    if (!!multiples) {
        json = new Map(Object.entries(json));
        json.forEach((value, key, map) => {
            csv += fetchAll(value, headers);

        });
    } else csv += fetchAll(json, headers);

    return csv;
};


const addHeaders = function (headers, csv) {
    for (let i = 0; i < headers.length - 1; i++) {
        csv += headers[i] + ","
    }
    csv += headers[headers.length - 1];
    csv += '\n';
    return csv;
}

const fetchAll = function (json, headers) {
    csv = "";
    headers.forEach((header) => {
        csv += fetch(header, json);
    });
    if (csv[csv.length - 1] == ',')
        csv = csv.substring(0, csv.length - 1);
    csv += '\n';
    return csv;
}

const fetch = function (path, json) {
    if (path.includes('.')) {
        return fetch(path.substring(path.indexOf('.') + 1), json[path.substring(0, path.indexOf('.'))]);
    } else {
        print(path, json[path]);
        if (json[path] == undefined || json[path] == 'object')
            general.printError("ERROR your json file is too nested please set the third parameter to true when you call (jsonToCsv)\nOr if the third parameter is already set to true then please be carefull in the second paramter which is the headers each one should an accurate path in the json")
        else if (typeof json[path] == 'number' || typeof json[path] == 'boolean')
            return json[path] + ",";
        else if (json[path].includes(','))
            json[path].replace(',', '.');
        return json[path] + ",";
    }
}

==> nested_json_to_csv-1.2.0.tgz: package/nestedJsonToCsv.js <==
const general = require('./generalFunctions.js');

exports.nestedJsonToCsv = (json, headers, multiples) => {

    if (headers == undefined || headers == []) {
        general.printError("Please pass an array of strings as a second parameter(headers)");
        //TODO: add a documentation link for this
        throw new Error;
    }

    let csv = "";

    csv = addHeaders(headers, csv);
    if (!!multiples) {
        json = new Map(Object.entries(json));
        json.forEach((value, key, map) => {
            csv += fetchAll(value, headers);

        });
    } else csv += fetchAll(json, headers);

    return csv;
};


const addHeaders = function (headers, csv) {
    for (let i = 0; i < headers.length - 1; i++) {
        csv += headers[i] + ","
    }
    csv += headers[headers.length - 1];
    csv += '\n';
    return csv;
}

const fetchAll = function (json, headers) {
    csv = "";
    headers.forEach((header) => {
        csv += fetch(header, json);
    });
    if (csv[csv.length - 1] == ',')
        csv = csv.substring(0, csv.length - 1);
    csv += '\n';
    return csv;
}

const fetch = function (path, json) {
    if (path.includes('.')) {
        return fetch(path.substring(path.indexOf('.') + 1), json[path.substring(0, path.indexOf('.'))]);
    } else {
        console.log(path, json[path]);
        if (json[path] == undefined || json[path] == 'object')
            general.printError("ERROR your json file is too nested please set the third parameter to true when you call (jsonToCsv)\nOr if the third parameter is already set to true then please be carefull in the second paramter which is the headers each one should an accurate path in the json")
        else if (typeof json[path] == 'number' || typeof json[path] == 'boolean')
            return json[path] + ",";
        else if (json[path].includes(','))
            json[path].replace(',', '.');
        return json[path] + ",";
    }
}
